/**
 * DK Maternity Facade API
 * This is the specification of the DK Maternity Facade API. It is a facade for the Web Services Resource Transfer DK Maternity API.
 *
 * OpenAPI spec version: 3.0.0
 *
 *
 */
/* tslint:disable:no-unused-variable member-ordering */

import {Inject, Injectable, Optional} from '@angular/core';
import {HttpClient} from '@angular/common/http';

import {Observable} from 'rxjs';

import {BASE_PATH} from '../variables';
import {Configuration} from '../configuration';
import {DataCard} from '../model/dataCard';
import {DataCardResponse} from '../model/dataCardResponse';


@Injectable()
export class DataCardService {

  protected basePath = '/';
  public configuration = new Configuration();

  constructor(
    protected httpClient: HttpClient,
    @Optional() @Inject(BASE_PATH) basePath: string,
    @Optional() configuration: Configuration
  ) {
    if (basePath) {
      this.basePath = basePath;
    }
    if (configuration) {
      this.configuration = configuration;
      this.basePath = basePath || configuration.basePath || this.basePath;
    }
  }

  public maternityDataCardGetAll(): Observable<DataCardResponse[]> {
    return this.httpClient.get<DataCardResponse[]>(`${this.basePath}/maternity/v1/data-card`);
  }

  public maternityDataCardCreate(): Observable<DataCard> {
    return this.httpClient.post<DataCardResponse>(`${this.basePath}/maternity/v1/data-card`,
     null);
  }

  public maternityDataCardGetActive(): Observable<DataCardResponse> {
    // Needs X-Episode-Of-Care-Identifier header
    return this.httpClient.get<DataCardResponse>(`${this.basePath}/maternity/v1/data-card/active`);
  }
  public maternityDataCardDeleteActive(): Observable<any> {
    // Needs X-Episode-Of-Care-Identifier header
    return this.httpClient.delete<DataCardResponse>(`${this.basePath}/maternity/v1/data-card/active`);
  }

  public maternityDataCardPut(
    documentUniqueId: string,
    version: string,
    request: DataCard): Observable<DataCardResponse> {
    // Needs X-Episode-Of-Care-Identifier header
    return this.httpClient.put<DataCardResponse>(
      `${this.basePath}/maternity/v1/data-card/${documentUniqueId}/${version}`
      , request
    );
  }
}
