import {Injectable} from '@angular/core';
import {ApiService} from './api.service';
import {HttpClient, HttpErrorResponse} from '@angular/common/http';
import {apiUrls} from '../../utils/urls';
import {DataCard, DataCardResponse} from '@nspop/gm-web-facade-api';
import {Observable, throwError} from 'rxjs';
import {BadInputError, CprDoesNotExistError, PageNotFoundError} from '../services/error.service';

@Injectable({
  providedIn: 'root',
})
export class DataCardService extends ApiService {

  constructor(httpClient: HttpClient) {
    super(apiUrls.dataCard, httpClient);
  }

  public create(): Observable<DataCardResponse> {
    return super.create(null);
  }

  public update(resource: DataCard, documentUniqueId: string, version: string): Observable<DataCardResponse> {
    return super.update(resource, documentUniqueId, version);
  }

  protected handleGetAllError = (error: HttpErrorResponse): Observable<never> => {
    if (error.status === 400) {
      return throwError(new CprDoesNotExistError(error));
    }

    if (error.status === 404) {
      return throwError(new CprDoesNotExistError(error));
    }
    return super.handleGetAllError(error);
  }
}
