import { Injectable } from '@angular/core';
import {ApiService} from './api.service';
import {HttpClient} from '@angular/common/http';
import {apiUrls} from '../../utils/urls';
import {Observable} from 'rxjs';
import {CreateUltrasoundObservationsRequest, ObservationTable} from '@nspop/gm-web-facade-api/index';
import {CreateRegularObservationsRequest, ScanningObservationTable} from '@nspop/gm-web-facade-api';

@Injectable({
  providedIn: 'root'
})
export class ObservationService extends ApiService {

  constructor(httpClient: HttpClient) {
    super(apiUrls.observation, httpClient);
  }

  createUltrasoundObservations(observations: CreateUltrasoundObservationsRequest): Observable<void> {
    return this.extendUrlAndCall('/scan', () => super.create(observations));
  }

  createRegularObservations(observations: CreateRegularObservationsRequest): Observable<void> {
    return this.extendUrlAndCall('/regular', () => super.create(observations));
  }

  extendUrlAndCall(urlExtension: string, callback: () => Observable<any>): Observable<any> {
    const oldUrl = this.url;
    this.url += urlExtension;

    const obs = callback();

    this.url = oldUrl;

    return obs;
  }

  getUltrasoundObservationTable(): Observable<ScanningObservationTable> {
    return this.extendUrlAndCall('/table/scan', () => super.getAll());
  }

  getClinicalObservationTable(): Observable<ObservationTable> {
    return this.extendUrlAndCall('/table/clinical', () => super.getAll());
  }
}
