import {Component, ElementRef, HostListener, OnInit, ViewChild} from '@angular/core';
import {DataSourceService} from '../services/data-source.service';
import {
  ChronicDiseasesSection,
  DataCard,
  OverallAssessmentSectionAllOfPrenatalCareAssessment,
  PosNegEnum,
} from '@nspop/gm-web-facade-api';
import {ConditionsEnum} from '../../utils/enums';
import {ChronicDiseasesSectionAllOf} from '@nspop/gm-web-facade-api/model/chronicDiseasesSectionAllOf';
@Component({
  selector: 'app-general-information-bar',
  templateUrl: './general-information-bar.component.html',
  styleUrls: ['./general-information-bar.component.scss']
})
export class GeneralInformationBarComponent implements OnInit {
  @ViewChild('headerContainer') public headerContainer: ElementRef | undefined;
  public headerInScrollMode = false;

  public dataCard: DataCard | undefined;
  public chronicDiseases = 'Nej';
  public careLevel = '?';
  public rhesusType = '?';
  private conditionsEnum = ConditionsEnum;
  constructor(private dataSourceService: DataSourceService) { }

  ngOnInit(): void {
    this.dataSourceService.activeDataCard$
      .subscribe((dataCard: DataCard | undefined) => {
        this.dataCard = dataCard;
        this.chronicDiseases = this.computeSpecialConditions(
          this.dataCard?.chronicDiseasesSection
          || {dirty: false} as ChronicDiseasesSection); // TODO: Is missing modifiedTime and author!!
        this.careLevel = this.computeCareLevel(this.dataCard?.overallAssessmentSection?.prenatalCareAssessment?.careLevel);
        this.rhesusType = this.computeRhesusType(this.dataCard?.screeningsSection?.maternalRhDAntibody?.rhesusType);
      });
  }

  get expectedDateOfBirth(): {route: string, params: any} {
    if (this.dataCard?.expectedDateOfDeliverySection?.expectedDateOfDeliveryFromPrenatalUltrasoundScan) {
      return {
        route: '/undersøgelser-og-målinger',
        params: {tab: 1, highlight: 'birth-date-ultrasound-birth-date'}
      };
    }
    return {
      route: '/svangerskab',
      params: {tab: 1, highlight: 'terminsberegning'}
    };
  }

  public swapEncounter(): void {
    console.log('Swapping encounter..');
  }

  public finishEncounter(): void {
    console.log('Finish encounter..');
  }

  private computeCareLevel(carelevel?: OverallAssessmentSectionAllOfPrenatalCareAssessment.CareLevelEnum): string {
    switch (carelevel) {
      case 'basic':
        return '1';
      case 'extended':
        return '2';
      case 'specialistMultidisciplinaryTeam':
        return '3';
      case 'highRiskPregnancyCare':
        return '4';
      default:
        return '?';
    }
  }

  private computeRhesusType(type?: PosNegEnum): string {
    switch (type) {
      case 'positive':
        return 'Positiv';
      case 'negative':
        return 'Negativ';
      default:
        return '?';
    }
  }

  private computeSpecialConditions(chronicDiseasesSection: ChronicDiseasesSection): string {
    console.log('ChronicDiseasesSectionType', ChronicDiseasesSection);
    console.log('ChronicDiseasesSectionAllOfType', ChronicDiseasesSectionAllOf);
    if (!chronicDiseasesSection.conditions){
      return 'nej';
    }
    return chronicDiseasesSection.conditions.map(
      key => {
        switch (key) {
          case ChronicDiseasesSection.ConditionsEnum.CirculatorySystem:
            return 'Kredsløbssygdomme';
          case ChronicDiseasesSection.ConditionsEnum.RespiratorySystem:
            return 'Åndedrætssystem';
          case ChronicDiseasesSection.ConditionsEnum.Thyroid:
            return 'Skjoldbruskkirtel';
          case ChronicDiseasesSection.ConditionsEnum.Diabetes:
            return 'Diabetes';
          // case this.conditionsEnum.CirculatorySystem:
          //   return 'Kredsløbssygdomme';
          // case this.conditionsEnum.RespiratorySystem:
          //   return 'Åndedrætssystem';
          // case this.conditionsEnum.Thyroid:
          //   return 'Skjoldbruskkirtel';
          // case this.conditionsEnum.Diabetes:
          //   return 'Diabetes';
          default:
            return '';
        }}
    ).join(', ');
  }

  @HostListener('window:scroll', ['$event']) // for window scroll events
  public onScroll($event: Event): void {
    if (this.headerContainer) {
      const elemTop = this.headerContainer.nativeElement.getBoundingClientRect().top;
      this.headerInScrollMode = elemTop <= 0;
    }
  }

}
