import {Component, OnInit, ViewChild} from '@angular/core';
import {DataCard, DataCardResponse} from '@nspop/gm-web-facade-api';
import {DataSourceService} from '../services/data-source.service';
import {NgForm} from '@angular/forms';
import {FormComponent} from '../confirm-navigation-if-dirty.framework';
import {finalize} from 'rxjs/operators';
import {copy} from '../../utils/copy';

@Component({
  selector: 'app-pregnancy',
  templateUrl: './pregnancy.component.html',
  styleUrls: ['./pregnancy.component.scss']
})
export class PregnancyComponent extends FormComponent implements OnInit {
  public dataCard: DataCard | undefined;
  public disableSaveButton = false;
  @ViewChild('form', {static: true}) form: NgForm|undefined;
  private documentUniqueId = '';
  private version = '';


  constructor(private dataSourceService: DataSourceService) { super(); }

  ngOnInit(): void {
    this.dataSourceService.activeDataCard$.subscribe((card: DataCardResponse | undefined) => {
      if (card) {
        const {documentUniqueId, version, episodeOfCareIdentifier, ...dataCard} = card;
        this.dataCard = copy(dataCard);
        this.documentUniqueId = documentUniqueId ?? '';
        this.version = version ?? '';
      }
    });
  }

  public save(): void {
    if (this.form?.valid) {
      this.disableSaveButton = true;
      this.dataSourceService.updateDataCard(this.dataCard as DataCard, this.documentUniqueId, this.version)
        .pipe(finalize(() => this.disableSaveButton = false))
        .subscribe(() => {
          this.dataSourceService.refresh();
          this.form?.form.markAsPristine();
        });
    }
  }
}
